OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Ugrađena poruka %s",
    "Important mail" : "Važna pošta",
    "Unread mail" : "Nepročitana pošta",
    "Important" : "Važno",
    "Work" : "Posao",
    "Personal" : "Osobno",
    "To Do" : "Zadatak",
    "Later" : "Kasnije",
    "Mails" : "Pošta",
    "Mail" : "Pošta",
    "💌 A mail app for Nextcloud" : "💌 Aplikacija za upravljanje e-poštom za Nextcloud",
    "Drafts are saved in:" : "Skice se spremaju u:",
    "Sent messages are saved in:" : "Poslane poruke spremaju se u:",
    "Deleted messages are moved in:" : "Izbrisane poruke spremaju se u:",
    "Auto" : "Auto",
    "Name" : "Naziv",
    "Mail address" : "Email adresa",
    "Password" : "Zaporka",
    "Manual" : "Ručno",
    "IMAP Settings" : "Postavke IMAP-a",
    "IMAP Host" : "IMAP poslužitelj",
    "IMAP Security" : "Sigurnost IMAP-a",
    "None" : "Nema",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP korisničko ime",
    "IMAP Password" : "IMAP zaporka",
    "SMTP Settings" : "Postavke SMTP-a",
    "SMTP Host" : "SMTP poslužitelj",
    "SMTP Security" : "Sigurnost SMTP-a",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP korisničko ime",
    "SMTP Password" : "SMTP zaporka",
    "Connecting" : "Povezivanje",
    "Save" : "Spremi",
    "Connect" : "Poveži",
    "Password required" : "Potrebna zaporka",
    "Account settings" : "Postavke računa",
    "Signature" : "Potpis",
    "A signature is added to the text of new messages and replies." : "Tekstu novih poruka i odgovora dodaje se potpis.",
    "Writing mode" : "Način pisanja",
    "Preferred writing mode for new messages and replies." : "Željeni način pisanja za nove poruke i odgovore.",
    "Default folders" : "Zadane mape",
    "Sieve filter rules" : "Pravila filtra Sieve",
    "Trusted senders" : "Pouzdani pošiljatelji",
    "Mail server" : "Poslužitelj e-pošte",
    "Sieve filter server" : "Poslužitelj filtra Sieve",
    "Update alias" : "Ažuriraj pseudonim",
    "Show update alias form" : "Prikaži obrazac za ažuriranje pseudonima",
    "Delete alias" : "Izbriši pseudonim",
    "Change name" : "Promijeni ime",
    "Email address" : "Adresa e-pošte",
    "Add alias" : "Dodaj pseudonim",
    "Create alias" : "Stvori pseudonim",
    "Cancel" : "Odustani",
    "Add mail account" : "Dodaj račun e-pošte",
    "Use Gravatar and favicon avatars" : "Upotrijebi avatare Gravatar i Favicon",
    "Register as application for mail links" : "Registriraj kao aplikaciju za poveznice e-pošte",
    "Show keyboard shortcuts" : "Prikaži tipkovne prečace",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Dopustite aplikaciji da prikuplja podatke o vašim interakcijama. Aplikacija će se prilagoditi vašim željama na temelju tih podataka. Podaci će biti pohranjeni samo lokalno.",
    "Put my text to the bottom of a reply instead of on top of it." : "Stavite tekst na dno odgovora umjesto na vrh.",
    "Automatically classify importance of new email" : "Automatski klasificirajte važnost nove e-pošte",
    "Could not update preference" : "Ažuriranje postavki nije uspjelo",
    "From" : "Od",
    "Select account" : "Odaberi račun",
    "To" : "Do",
    "Contact or email address …" : "Kontakt ili adresa e-pošte...",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "No contacts found." : "Nikakvi kontakti nisu nađeni.",
    "Subject" : "Predmet",
    "Subject …" : "Naslov...",
    "This message came from a noreply address so your reply will probably not be read." : "Ova je poruka poslana s adrese na koju se ne može odgovoriti pa vaš odgovor vjerojatno nitko neće pročitati.",
    "The following recipients do not have a PGP key: {recipients}." : "Sljedeći primatelji nemaju PGP-ključ: {recipients}.",
    "Write message …" : "Napiši poruku...",
    "Saving draft …" : "Spremanje skice...",
    "Draft saved" : "Skica je spremljena",
    "Upload attachment" : "Otpremi privitak",
    "Add attachment from Files" : "Dodaj privitak iz datoteka",
    "Add link" : "Dodaj poveznicu",
    "Enable formatting" : "Omogući oblikovanje",
    "Request a read receipt" : "Zatražite potvrdu o čitanju",
    "Encrypt message with Mailvelope" : "Šifriraj poruku s Mailvelope",
    "Enter a date" : "Unesi datum",
    "Add share link from {productName} Files" : "Dodaj poveznicu za dijeljenje iz datoteka {productName}",
    "Send" : "Pošalji",
    "Message {id} could not be found" : "Poruka {id} nije pronađena",
    "Choose a file to add as attachment" : "Izaberi datoteku kao privitak",
    "Choose a file to share as a link" : "Izaberi datoteku za dijeljenje putem poveznice",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Privitak prekoračuje dopuštenu veličinu privitaka od {size}. Dijelite datoteku putem poveznice.","Privici prekoračuju dopuštenu veličinu privitaka od {size}. Dijelite datoteke putem poveznice.","Privici prekoračuju dopuštenu veličinu privitaka od {size}. Dijelite datoteke putem poveznice."],
    "No message found yet" : "Nije pronađena nijedna poruka",
    "Set up an account" : "Postavi račun",
    "Plain text" : "Običan tekst",
    "Rich text" : "Bogat tekst",
    "No messages in this mailbox" : "Nema poruka u ovom sandučiću",
    "No messages" : "Nema poruka",
    "Draft: " : "Skica: ",
    "Unfavorite" : "Ukloni iz favorita",
    "Favorite" : "Favorit",
    "Read" : "Čitaj",
    "Mark not spam" : "Označi da nije neželjena pošta",
    "Mark as spam" : "Označi kao neželjenu poštu",
    "Unselect" : "Poništi odabir",
    "Select" : "Odaberi",
    "Edit tags" : "Uredi oznake",
    "Move thread" : "Premjesti dretvu",
    "Delete thread" : "Izbriši dretvu",
    "More actions" : "Dodatne radnje",
    "Edit as new message" : "Uredi kao novu poruku",
    "Create event" : "Stvori događaj",
    "Blind copy recipients only" : "Samo primatelji skrivenih kopija poruke",
    "No trash mailbox configured" : "Nije konfiguriran sandučić za izbrisanu poštu",
    "Could not delete message" : "Brisanje poruke nije uspjelo",
    "Forward" : "Naprijed",
    "Load more" : "Učitaj više",
    "_Mark {number} unread_::_Mark {number} unread_" : ["Označi {number} kao nepročitano","Označi {number} kao nepročitano","Označi {number} kao nepročitano"],
    "_Mark {number} read_::_Mark {number} read_" : ["Označi {number} kao pročitano","Označi {number} kao pročitano","Označi {number} kao pročitano"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Označi {number} kao važan","Označi {number} kao važan","Označi {number} kao važan"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Označi {number} kao nevažan","Označi {number} kao nevažan","Označi {number} kao nevažan"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Ukloni {number} iz favorita","Ukloni {number} iz favorita","Ukloni {number} iz favorita"],
    "_Favorite {number}_::_Favorite {number}_" : ["Dodaj {number} u favorite","Dodaj {number} u favorite","Dodaj {number} u favorite"],
    "_Unselect {number}_::_Unselect {number}_" : ["Poništi odabir {number}","Poništi odabir {number}","Poništi odabir {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["Premjesti {number} dretvu","Premjesti {number} dretve","Premjesti {number} dretvi"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Proslijedi {number} kao privitak","Proslijedi {number} kao privitak","Proslijedi {number} kao privitak"],
    "_Delete {number} thread_::_Delete {number} threads_" : ["Izbriši {number} dretvu","Izbriši {number} dretve","Izbriši {number} dretvi"],
    "Report this bug" : "Prijavi ovu pogrešku",
    "All day" : "Cijeli dan",
    "Create" : "Stvori",
    "Event created" : "Događaj je stvoren",
    "Could not create event" : "Nije moguće stvoriti događaj",
    "Comment" : "Komentar",
    "Accept" : "Prihvati",
    "Decline" : "Odbij",
    "More options" : "Više mogućnosti",
    "Could not open mailbox" : "Nije moguće otvoriti sandučić",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksiranje poruka u tijeku. Ova radnja može potrajati za veće sandučiće.",
    "Choose target mailbox" : "Odaberi ciljni sandučić",
    "No more submailboxes in here" : "Ovdje više nema podsandučića",
    "Choose" : "Odaberite",
    "Important info" : "Važne informacije",
    "Other" : "Ostalo",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Poruke se automatski označavaju kao važne na temelju poruka kojima ste rukovali ili koje ste označili kao važne. U početku ćete možda morati ručno mijenjati važnost poruka kako bi sustav zapamtio vaše želje, ali s vremenom će se poboljšati.",
    "The sender of this message has asked to be notified when you read this message." : "Pošiljatelj ove poruke zatražio je da bude obaviješten kad pročitate ovu poruku.",
    "Notify the sender" : "Obavijestite pošiljatelja",
    "You sent a read confirmation to the sender of this message." : "Poslali ste potvrdu o čitanju pošiljatelju ove poruke.",
    "Could not send mdn" : "Nije moguće poslati mdn",
    "Reply" : "Odgovori",
    "Reply to sender only" : "Odgovori pošiljatelju",
    "Move message" : "Premjesti poruku",
    "View source" : "Vidi izvor",
    "Download thread data for debugging" : "Preuzmi podatke o dretvi radi otklanjanje pogrešaka",
    "Message source" : "Izvor poruke",
    "Message body" : "Tijelo poruke",
    "Import into calendar" : "Dodaj u kalendar",
    "Download attachment" : "Preuzmi privitak",
    "Save to Files" : "Spremi u datoteke",
    "Unnamed" : "Neimenovano",
    "Embedded message" : "Ugrađena poruka",
    "Choose a folder to store the attachment in" : "Izaberi mapu za spremanje privitka",
    "Save all to Files" : "Spremi sve u datoteke",
    "Download Zip" : "Preuzmi Zip",
    "Choose a folder to store the attachments in" : "Izaberi mapu za spremanje privitaka",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Ova je poruka šifrirana PGP-om. Instalirajte Mailvelope kako biste je dešifrirali.",
    "The images have been blocked to protect your privacy." : "Slike su blokirane u svrhu zaštite privatnosti.",
    "Show images" : "Prikaži slike",
    "Show images temporarily" : "Privremeno prikaži slike",
    "Always show images from {sender}" : "Uvijek prikaži slike od {sender}",
    "Always show images from {domain}" : "Uvijek prikaži slike s {domain}",
    "Message frame" : "Okvir poruke",
    "Quoted text" : "Citirani tekst",
    "Move" : "Premjesti",
    "Moving" : "Premještanje",
    "Moving thread" : "Premještanje dretve",
    "Moving message" : "Premještanje poruke",
    "Quota" : "Kvota",
    "Show only subscribed mailboxes" : "Prikaži samo pretplaćene sandučiće",
    "Add mailbox" : "Dodaj sandučić",
    "Saving" : "Spremanje",
    "Move up" : "Premjesti gore",
    "Move down" : "Premjesti dolje",
    "Remove account" : "Izbriši račun",
    "Loading …" : "Učitavanje…",
    "Not supported by the server" : "Ne podržava poslužitelj",
    "{usage} of {limit} used" : "{usage} od {limit} iskorišteno",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Račun za {email} i podaci e-pošte spremljeni u predmemoriji uklonit će se iz Nextclouda, ali ne iz vašeg davatelja usluga e-pošte.",
    "Remove account {email}" : "Ukloni račun {email}",
    "Remove {email}" : "Ukloni {email}",
    "Show all subscribed mailboxes" : "Prikaži sve pretplaćene sandučiće",
    "Show all mailboxes" : "Prikaži sve sandučiće",
    "Collapse mailboxes" : "Sakrij sandučiće",
    "Mark all as read" : "Označi sve kao pročitano",
    "Mark all messages of this mailbox as read" : "Označi sve poruke u ovom sandučiću kao pročitane",
    "Add submailbox" : "Dodaj podsandučić",
    "Edit name" : "Uredi naziv",
    "Clear cache" : "Izbriši predmemoriju",
    "Clear locally cached data, in case there are issues with synchronization." : "Izbrišite podatke iz lokalnog međuspremnika u slučaju da postoje problemi sa sinkronizacijom.",
    "Subscribed" : "Pretplaćen",
    "Sync in background" : "Sinkronizacija u pozadini",
    "Delete mailbox" : "Izbriši sandučić",
    "The mailbox and all messages in it will be deleted." : "Izbrisat će se sandučić i sve pripadajuće poruke.",
    "Delete mailbox {name}" : "Izbriši sandučić {name}",
    "An error occurred, unable to rename the mailbox." : "Došlo je do pogreške, nije moguće promijeniti naziv sandučića.",
    "_{total} message_::_{total} messages_" : ["{total} poruka","{total} poruka","{total} poruka"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nepročitana od {total}","{unread} nepročitane od {total}","{unread} nepročitanih od {total}"],
    "New message" : "Nova poruka",
    "Error sending your message" : "Pogreška pri slanju poruke",
    "Go back" : "Natrag",
    "Retry" : "Pokušaj ponovno",
    "Uploading attachments …" : "Otpremanje privitaka...",
    "Sending …" : "Slanje…",
    "Warning sending your message" : "Upozorenje pri slanju poruke",
    "Send anyway" : "Svejedno pošalji",
    "No sent mailbox configured. Please pick one in the account settings." : "Nije konfiguriran sandučić za poslanu poštu. Odaberite ga u postavkama računa.",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Pokušavate poslati poruku velikom broju primatelja koji su navedeni u poljima Za i/ili Cc. Razmislite o korištenju polja Bcc kako adrese primatelja ne bi bile vidljive.",
    "No message selected" : "Nije odabrana nijedna poruka",
    "Message" : "Poruka",
    "Oh Snap!" : "Oh Snap!",
    "Delete" : "Izbriši",
    "Contacts with this address" : "Kontakti s ovom adresom",
    "Add to Contact" : "Dodaj kontaktu",
    "New Contact" : "Novi kontakt",
    "Copy to clipboard" : "Kopiraj u međuspremnik",
    "Contact name …" : "Naziv kontakta…",
    "Add" : "Dodaj",
    "Tags" : "Oznake",
    "Select tags" : "Odaberite oznake",
    "Clear" : "Izbriši",
    "Search" : "Traži",
    "Date" : "Datum",
    "Disabled" : "Onemogućeno",
    "Enabled" : "Omogućeno",
    "Sieve Host" : "Sieve poslužitelj",
    "Sieve Security" : "Sieve sigurnost",
    "Sieve Port" : "Sieve port",
    "Sieve Credentials" : "Vjerodajnice za Sieve",
    "IMAP Credentials" : "Vjerodajnice za IMAP",
    "Custom" : "Prilagođeno",
    "Sieve User" : "Sieve korisnik",
    "Sieve Password" : "Sieve zaporka",
    "Save sieve settings" : "Spremi postavke za Sieve",
    "Save sieve script" : "Spremi Sieve skriptu",
    "Signature …" : "Potpis...",
    "Save signature" : "Spremi potpis",
    "Place signature above quoted text" : "Stavi potpis iznad citiranog teksta",
    "Add default tags" : "Dodaj zadane oznake",
    "Rename tag" : "Preimenuj oznaku",
    "Saving new tag name …" : "Spremanje novog naziva oznake…",
    "Set" : "Postavi",
    "Unset" : "Ukloni",
    "Add tag" : "Dodaj oznaku",
    "Saving tag …" : "Spremanje oznake...",
    "Tag already exists" : "Oznaka već postoji",
    "An error occurred, unable to create the tag." : "Došlo je do pogreške, nije moguće stvoriti oznaku.",
    "An error occurred, unable to rename the tag." : "Došlo je do pogreške, nije moguće promijeniti naziv oznake.",
    "Not found" : "Nije pronađeno",
    "Could not load your message thread" : "Učitavanje vaše dretve poruka nije uspjelo",
    "Mark as unread" : "Označi kao nepročitano",
    "Mark as read" : "Označi kao pročitano",
    "Delete message" : "Izbriši poruku",
    "Remove" : "Ukloni",
    "No senders are trusted at the moment." : "Trenutno nema pouzdanih pošiljatelja.",
    "Could not remove trusted sender {sender}" : "Nije moguće ukloniti pouzdanog pošiljatelja {sender}",
    "individual" : "pojedinac",
    "domain" : "domena",
    "(organizer)" : "(organizator)",
    "Untitled event" : "Događaj bez naslova",
    "Import into {calendar}" : "Uvezi u {calendar}",
    "Event imported into {calendar}" : "Događaj je uvezen u {calendar}",
    "Airplane" : "Zrakoplov",
    "Reservation {id}" : "Rezervacija {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Let {flightNr} iz {depAirport} do {arrAirport}",
    "Train" : "Vlak",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iz {depStation} do {arrStation}",
    "Train from {depStation} to {arrStation}" : "Vlak iz {depStation} do {arrStation}",
    "Mail app" : "Aplikacija za upravljanje e-poštom",
    "The mail app allows users to read mails on their IMAP accounts." : "Aplikacija za upravljanje e-poštom omogućuje korisnicima da čitaju svoje poruke s IMAP računa.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Ovdje možete pronaći postavke za čitavu instancu. Postavke za pojedinog korisnika nalaze se u samoj aplikaciji (donji lijevi kut).",
    "Account provisioning" : "Uspostavljanje računa",
    "A provisioning configuration will provision all accounts with a matching email address." : "Konfiguracija dodjeljivanja omogućit će sve račune s odgovarajućom adresom e-pošte.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Korištenje zamjenskog znaka (*) u polju domene dodjeljivanja stvorit će konfiguraciju koja se primjenjuje na sve korisnike pod uvjetom da se ne podudaraju s drugom konfiguracijom.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Mehanizam dodjeljivanja daje prednost konfiguracijama određene domene nad konfiguracijom zamjenske domene.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Ako se pronađe nova podudarna konfiguracija nakon što je korisniku već dodijeljena druga konfiguracija, nova će konfiguracija imati prednost i korisniku će se ponovno dodijeliti konfiguracija.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "Domena može imati samo jednu konfiguraciju i može postojati samo jedna zamjenska konfiguracija domene.",
    "These settings can be used in conjunction with each other." : "Ove se postavke mogu upotrebljavati u kombinaciji.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "Ako želite dodijeliti samo jednu domenu za sve korisnike, upotrijebite zamjenski znak (*).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Ova postavka ima smisla samo ako upotrebljavate isti korisnički pozadinski sustav za svoj Nextcloud i poslužitelj e-pošte organizacije.",
    "Provisioning Configurations" : "Konfiguracije uspostavljanja",
    "Add new config" : "Dodaj novu konfiguraciju",
    "Provision all accounts" : "Dodijeli sve račune",
    "Anti Spam Service" : "Usluga za sprječavanje neželjene pošte",
    "You can set up an anti spam service email address here." : "Ovdje možete postaviti adresu e-pošte za uslugu sprječavanja neželjene pošte.",
    "Any email that is marked as spam will be sent to the anti spam service." : "Svaka poruka e-pošte koja je označena kao neželjena pošta šalje se usluzi za sprječavanje neželjene pošte.",
    "Successfully updated config for \"{domain}\"" : "Konfiguracija za „{domain}“ je uspješno ažurirana",
    "Error saving config" : "Pogreška pri spremanju konfiguracije",
    "Saved config for \"{domain}\"" : "Konfiguracija za „{domain}“ je spremljena",
    "Could not save provisioning setting" : "Spremanje postavke dodjeljivanja nije uspjelo",
    "There was an error when provisioning accounts." : "Došlo je do pogreške pri dodjeljivanju računa.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Računima za „{domain}“ je ukinuto dodjeljivanje i izbrisani su",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Pogreška pri brisanju i ukidanju dodjele računa za „{domain}“",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Dodjeljivanje je uspješno izvedeno za {count} račun.","Dodjeljivanje je uspješno izvedeno za {count} računa.","Dodjeljivanje je uspješno izvedeno za {count} računa."],
    "Anti Spam" : "Sprječavanje neželjene pošte",
    "Add the email address of your anti spam report service here." : "Ovdje dodajte adresu e-pošte svoje usluge za prijavljivanje neželjene pošte.",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Kada upotrebljavate ovu postavku, poruka e-pošte s prijavom šalje se poslužitelju za prijavu neželjene pošte kada korisnik klikne na „Označi kao neželjenu poštu”.",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Izvorna poruka bit će priložena kao privitak „message/rfc822”.",
    "\"Mark as Spam\" Email Address" : "Adresa e-pošte „Označi kao neželjenu poštu”",
    "\"Mark Not Junk\" Email Address" : "Adresa e-pošte „Označi da nije neželjena pošta”",
    "Reset" : "Resetiraj",
    "Successfully set up anti spam email addresses" : "Uspješno postavljene adrese e-pošte za sprječavanje neželjene pošte",
    "Error saving anti spam email addresses" : "Pogreška pri spremanju adresa e-pošte za sprječavanje neželjene pošte",
    "Successfully deleted anti spam reporting email" : "Uspješno izbrisana adresa e-pošte za prijavu neželjene pošte",
    "Error deleting anti spam reporting email" : "Pogreška pri brisanju adrese e-pošte za prijavu neželjene pošte",
    "Client ID" : "ID klijenta",
    "Client secret" : "Tajni ključ klijenta",
    "Domain Match: {provisioningDomain}" : "Podudaranje domene: {provisioningDomain}",
    "Email: {email}" : "E-pošta: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} na {host}:{port} ({ssl} šifriranje)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} na {host}:{port} ({ssl} šifriranje)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} na {host}:{port} ({ssl} šifriranje)",
    "Configuration for \"{provisioningDomain}\"" : "Konfiguracija za „{provisioningDomain}“",
    "General" : "Općenito",
    "Provisioning domain" : "Dodjeljivanje domene",
    "Email address template" : "Predložak adrese e-pošte",
    "IMAP" : "IMAP",
    "User" : "Korisnik",
    "Host" : "Glavno računalo",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Omogućite Sieve integraciju",
    "LDAP aliases integration" : "Integracija pseudonima za LDAP",
    "Enable LDAP aliases integration" : "Omogući integraciju pseudonima za LDAP",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "Integracija pseudonima za LDAP čita atribut iz konfiguriranog LDAP direktorija radi dodjeljivanja pseudonima e-pošte.",
    "LDAP attribute for aliases" : "LDAP atribut za pseudonime",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Viševrijednosni atribut za dodjeljivanje pseudonima e-pošte. Za svaku se vrijednost stvara pseudonim. Brišu se pseudonimi koji postoje u Nextcloudu, ali koji nisu u LDAP direktoriju.",
    "Save Config" : "Spremi konfiguraciju",
    "Unprovision & Delete Config" : "Ukini dodjelu i izbriši konfiguraciju",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% i %EMAIL% bit će zamijenjeni korisničkim UID-om i e-poštom",
    "With the settings above, the app will create account settings in the following way:" : "Aplikacija će primijeniti navedene postavke i stvoriti račun na sljedeći način:",
    "E-mail address" : "Adresa e-pošte",
    "Valid until" : "Vrijedi do",
    "Certificate" : "Vjerodajnica",
    "Back" : "Natrag",
    "Submit" : "Šalji",
    "Keyboard shortcut" : "Tipkovni prečac",
    "Keyboard shortcuts" : "Tipkovni prečaci",
    "Speed up your Mail experience with these quick shortcuts." : "Ubrzajte korištenje e-pošte s pomoću ovih brzih prečaca.",
    "Compose new message" : "Sastavi novu poruku",
    "Newer message" : "Novija poruka",
    "Older message" : "Starija poruka",
    "Toggle star" : "Uključi/isključi zvijezdu",
    "Toggle unread" : "Uključi/isključi nepročitano",
    "Archive" : "Arhiva",
    "Refresh" : "Osvježi",
    "Account connected" : "Račun povezan",
    "Connect your mail account" : "Poveži svoj račun e-pošte",
    "Itinerary for {type} is not supported yet" : "Raspored za {type} još uvijek nije podržan",
    "All" : "Sve",
    "Drafts" : "Skice",
    "Favorites" : "Favoriti",
    "Priority inbox" : "Prioritetni sandučić",
    "All inboxes" : "Sve dolazne",
    "Inbox" : "Dolazni sandučić",
    "Junk" : "Neželjeno",
    "Sent" : "Poslano",
    "Trash" : "Smeće",
    "Error while sharing file" : "Pogreška pri dijeljenju datoteke",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nova poruka \nod {from}","%n novih poruka \nod {from}","%n novih poruka \nod {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Attachments were not copied. Please add them manually." : "Privici nisu kopirani. Dodajte ih ručno.",
    "Message sent" : "Poruka poslana",
    "Could not load {tag}{name}{endtag}" : "Pogreška pri učitavanju {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Došlo je do pogreške pri učitavanju {tag}{name}{endtag}",
    "Could not load your message" : "Učitavanje vaše poruke nije uspjelo",
    "Could not load the desired message" : "Ne može se učitati željena poruka",
    "Could not load the message" : "Poruku nije moguće učitati",
    "Error loading message" : "Pogreška pri učitavanju poruke",
    "Forwarding to %s" : "Prosljeđivanje %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Kliknite ovdje ako niste preusmjereni automatski unutar sljedećih nekoliko sekundi.",
    "Redirect" : "Preusmjeri",
    "The link leads to %s" : "Ova poveznica vodi do %s",
    "Continue to %s" : "Idi do %s"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
